@@ -162,9 +162,11 @@ class Target:
 
     """
 
-    def __init__(self, mag, magsystem, filt_range, sed=None, temp=5778):
+    def __init__(self, mag, magsystem='VEGAMAG', filt_range=None, sed=None, temp=5778):
 
         # Define the magnitude system.
+        if filt_range is None:
+            filt_range = [5000, 6000]
         if magsystem.lower() == 'vegamag':
             sys = units.VEGAMAG
         elif magsystem.lower() == 'stmag':
@@ -275,6 +277,7 @@ class Observation:
         self.slit_height = instrument.slit_height
         self.ranges = instrument.range
         self.Npix_lam = instrument.Npix_lam
+        self.name = instrument.name
 
         self.Npix, self.seeing_area = self.Npix()
         self.counts(self.source, instrument)
@@ -381,7 +384,7 @@ class Observation:
 
         """
         returnList = []
-
+        self.exptime = exptime
         for i, row in enumerate(self.names):
             if self.isImager == 0:
                 SN_d_lam = (self.s_prime_dlam[i][0] * exptime) / np.sqrt(self.s_prime_dlam[i][0] * exptime +
@@ -414,7 +417,7 @@ class Observation:
         """
 
         returnList = []
-
+        self.SigToNoise = SN
         for i, row in enumerate(self.names):
             if self.isImager == 0:
                 t_d_lam = (1. / (2. * self.s_prime_dlam[i][0] ** 2)) * (
@@ -438,11 +441,11 @@ class Instrument:
 
     It is important to note that since this exposure time calculator is designed for the Astrophysical Research
     Consortium (ARC) 3.5m telescope, the list of instruments available is exclusive to this telescope. That list is::
-        * ARCTIC        (Imager)
-        * AGILE         (Imager)
-        * ARCES         (Spectrograph)
+        * Arctic        (Imager)
+        * AGILE         (Imager) Not working yet
+        * Arces         (Spectrograph)
         * DIS           (Spectrograph)
-        * TRIPLESEC     (Spectrograph)
+        * TripleSpec     (Spectrograph)
         * NICFPS        (Spectrograph)
 
     Parameters
@@ -468,7 +471,7 @@ class Instrument:
         The plate scale of the instrument.
     """
 
-    def __init__(self, Instr_name, Telescope_name='apo3_5m'):
+    def __init__(self, Instr_name, Telescope_name='apo3_5m'):       # will add multi telescope support in future
 
         path = get_data(Telescope_name + '/' + Instr_name + "/" + Instr_name + '_param.yaml')
         with open(r''+ path) as file:
@@ -478,6 +481,7 @@ class Instrument:
         self.scale = param['plate_scale[arcsec/pix]']
         self.slit_height = param['Slit_height']
         self.element_num = param['filter/dispersion_Num']
+        self.name = Instr_name
 
         names = []
         efficiencies = []
